@@ -171,6 +171,14 @@ def format_default_translations_config(additional_languages):
     return "{{\n{0}\n}}".format("\n".join(lang_paths))
 
 
+def get_default_translations_dict(default_lang, additional_languages):
+    """Generate a TRANSLATIONS dict matching the config from 'format_default_translations_config'."""
+    tr = {default_lang: ''}
+    for l in additional_languages:
+        tr[l] = './' + l
+    return tr
+
+
 def format_navigation_links(additional_languages, default_lang, messages, strip_indexes=False):
     """Return the string to configure NAVIGATION_LINKS."""
     f = u"""\
@@ -353,9 +361,8 @@ class CommandInit(Command):
 
             # Get messages for navigation_links.  In order to do this, we need
             # to generate a throwaway TRANSLATIONS dict.
-            tr = {default: ''}
-            for l in langs:
-                tr[l] = './' + l
+            tr = get_default_translations_dict(default, langs)
+
             # Assuming that base contains all the locales, and that base does
             # not inherit from anywhere.
             try:
