@@ -946,6 +946,8 @@ def extract_all(zipfile, path='themes'):
 def to_datetime(value, tzinfo=None):
     """Convert string to datetime."""
     try:
+        if type(value) == datetime.date:
+            value = datetime.datetime.combine(value, datetime.time(0, 0))
         if not isinstance(value, datetime.datetime):
             # dateutil does bad things with TZs like UTC-03:00.
             dateregexp = re.compile(r' UTC([+-][0-9][0-9]:[0-9][0-9])')
